OutputWriter class

Helper for writting the putput files.

Mixed-in types

Constructors

OutputWriter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
renderData → Map<String, dynamic>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(String text) → String
inherited
toString() → String
A string representation of this object.
inherited
writeOutputs(List<OutputTask> tasks) → OutputWriter
Converts the given tasks into files and writes them.

Operators

operator ==(Object other) → bool
The equality operator.
inherited