RunCommandArgs class

Constructors

RunCommandArgs(ArgParser _parser, ArgResults _resultsProvier())

Properties

dataFilePaths → List<String>
no setter
hashCode → int
The hash code for this object.
no setterinherited
inputVariables → List<String>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskFlags → Map<String, String>
no setter
taskName → String
no setter

Methods

initOptions() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

kOptionInput → String
final
kOptionInputAbbr → String
final
kOptionInputFile → String
final
kOptionInputFileAbbr → String
final
kOptionTask → String
final
kOptionTaskAbbr → String
final